   SU=/bin/su
   LOGIN=/bin/login
   BACKUP=orig.b4opie
	if test ! -e ${LOGIN}.${BACKUP}; then echo "Renaming existing ${LOGIN} to ${LOGIN}.${BACKUP}"; mv ${LOGIN} ${LOGIN}.${BACKUP}; echo "Clearing permissions on old ${LOGIN}"; chmod 0 ${LOGIN}.${BACKUP}; ln -s /bin/opielogin ${LOGIN} ; fi
	if test ! -e ${SU}.${BACKUP}; then echo "Renaming existing su to su.${BACKUP}"; mv ${SU} ${SU}.${BACKUP}; echo "Clearing permissions on old su"; chmod 0 ${SU}.${BACKUP}; ln -s /bin/opiesu ${SU} ; fi
	
